[![Total alerts](https://img.shields.io/lgtm/alerts/g/RBrearton/local_stats.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/RBrearton/local_stats/alerts/)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/RBrearton/local_stats.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/RBrearton/local_stats/context:python)
[![codecov](https://codecov.io/gh/RBrearton/local_stats/branch/master/graph/badge.svg?token=FGIV0MVHS8)](https://codecov.io/gh/RBrearton/local_stats)
[![Actions Status](https://github.com/RBrearton/local_stats/workflows/pytest/badge.svg)](https://github.com/pytest/local_stats/actions)
[![Actions Status](https://github.com/RBrearton/local_stats/workflows/Pylint/badge.svg)](https://github.com/pytest/local_stats/actions)
[![Documentation Status](https://readthedocs.org/projects/local-stats/badge/?version=latest)](https://local-stats.readthedocs.io/en/latest/?badge=latest)

A python package for using local statistics to cluster significant signal in
scientific images.

Documentation can be found [here](https://local-stats.readthedocs.io/en/latest/?badge=latest).

To install, simply use

```bash
pip install local_stats
```

To install in developer mode:

```bash
git clone https://github.com/RBrearton/local_stats
cd local_stats
pip install -e .
```

Alternatively, the usual "python setup.py install" etc. will work, but
installation of dev mode with pip has obvious upsides (easier to manage etc.).
